#!/bin/ksh

ECHO="/bin/echo"
TRUE=0
FALSE=1

$ECHO "  "
$ECHO "Uninstall WebSphere Commerce 5.4.0.1 Professional Fixpack for Models"
$ECHO "Please shut down the Application Server and any Webservers that might be running"
$ECHO "  "

# print usage.
print_usage() {
   $ECHO "usage: `basename $0` <was_home>"
   $ECHO "where <was_home> is the directory where the IBM WebSphere Application Server(WAS) is installed"
   $ECHO "and <wc_home> is the directory where IBM WebSphere Commerce Professional is installed"
   $ECHO "Example: ./uninstall.sh /opt/WebSphere/AppServer /opt/WebSphere/CommerceServer"
}


# checks if required directories exist.
check_paths() {
local val=1

   if [ -d $WC_HOME ] && val=2 && [ -d $WAS_HOME ]
   then
#   	$ECHO "---- Components path check passed -----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "Invalid WC_HOME directory."
	      ;;
	   2) $ECHO "Invalid WAS_HOME directory."
	      ;;
	esac
   fi

   return $FALSE
}


# checks if required files exist.
check_files() {
local val=1

   if [ -f WCPro54ModelsUpdate1_SUN_backup.jar ] && val=2 && \
      [ -f WCPro54ModelsUpdate1_SUN.log ]
   then
#   	$ECHO "---- Files check passed ----"
	return $TRUE
   else
   	$ECHO "---- Please correct following error: ----"

	case $val in
	   1) $ECHO "The following file does not exist: WCPro54ModelsUpdate1_SUN_backup.jar"
	      ;;
	   2) $ECHO "The following file does not exist: WCPro54ModelsUpdate1_SUN.log"
	      ;;
	esac
   fi

   return $FALSE;
}



# beginning of script.
#clear

#ensure correct number of arguments provided.
if [ $# -ne 2 ]; then
   print_usage
   exit 0
else
   WC_HOME=$2
   WAS_HOME=$1
fi


# check if necessary components install path exist.
if check_paths; then
   $ECHO "main - check path PASSED."
else
   $ECHO "main - check path FAILED."
   exit 0
fi


WC_FP5401_DIR="$WAS_HOME/service/fixpack/5401"


# check if necessary files exist.
if check_files; then
   $ECHO "main - check files PASSED."
else
   $ECHO "main - check files FAILED."
   exit 0
fi


# Uninstall WebSphere Commerce 5.4.0.1 Professional Fixpack for Models, SUN
$ECHO "main - uninstalling fixpack."

$WAS_HOME/java/jre/bin/java -jar WCPro54ModelsUpdate1_SUN_backup.jar -log UninstallWCPro54ModelsUpdate1_SUN.log

$ECHO "main - uninstalling fixpack complete."

exit 0
